@@ -1,13 +1,13 @@
 import warnings
-from gambas.manager import ConfigContentManager
+from gambas.factory import get_manager
 
 
 class ConfigValidator:
   def __init__(self, default_filepath, target_filepath):
     self.__default_filepath = default_filepath
     self.__target_filepath = target_filepath
-    self.default_keys = ConfigContentManager(self.__default_filepath).get_key_list()
-    self.target_keys = ConfigContentManager(self.__target_filepath).get_key_list()
+    self.default_keys = get_manager(self.__default_filepath).get_key_list()
+    self.target_keys = get_manager(self.__target_filepath).get_key_list()
 
   def check_exist_keys(self, is_error=True):
     cand_key_list = [
